pub fn format_warnings(result: &EvaluationResult) -> Option<String>Expand description
Format enforcement results as a warning message for the user.
pub fn format_warnings(result: &EvaluationResult) -> Option<String>Format enforcement results as a warning message for the user.