is_disallowed_trigger

Function is_disallowed_trigger 

pub fn is_disallowed_trigger(trigger: &str) -> bool
True when a stored rule trigger is disallowed and should be reclaimed by the decay cycle. ONLY command_failure: triggers can be disallowed command triggers: file_churn:<path> (paths may contain =), multi_agent_start, and free-text triggers are never revoked by the decay cycle (GH-813).